@@ -1,17 +1,37 @@
+//! Support for Perl dependencies.
+//!
+//! This module provides functionality for working with Perl dependencies,
+//! including Perl modules, pre-declared dependencies, and file dependencies.
+
 use crate::dependency::Dependency;
 use crate::installer::{Error, Explanation, InstallationScope, Installer};
 use crate::session::Session;
 use serde::{Deserialize, Serialize};
-use std::path::Path;
 
 #[derive(Debug, Clone, Serialize, Deserialize)]
+/// A dependency on a Perl module.
+///
+/// This represents a dependency on a Perl module that needs to be installed
+/// for the code to function properly.
 pub struct PerlModuleDependency {
+    /// The name of the Perl module.
     pub module: String,
+    /// The optional filename that contains the module.
     pub filename: Option<String>,
+    /// Optional include paths for finding the module.
     pub inc: Option<Vec<String>>,
 }
 
 impl PerlModuleDependency {
+    /// Create a new Perl module dependency with filename and include paths.
+    ///
+    /// # Arguments
+    /// * `module` - The name of the Perl module
+    /// * `filename` - Optional filename that contains the module
+    /// * `inc` - Optional include paths for finding the module
+    ///
+    /// # Returns
+    /// A new PerlModuleDependency
     pub fn new(module: &str, filename: Option<&str>, inc: Option<Vec<&str>>) -> Self {
         Self {
             module: module.to_string(),
@@ -20,6 +40,13 @@ impl PerlModuleDependency {
         }
     }
 
+    /// Create a simple Perl module dependency with just a module name.
+    ///
+    /// # Arguments
+    /// * `module` - The name of the Perl module
+    ///
+    /// # Returns
+    /// A new PerlModuleDependency with no filename or include paths
     pub fn simple(module: &str) -> Self {
         Self {
             module: module.to_string(),
@@ -66,15 +93,29 @@ impl Dependency for PerlModuleDependency {
 impl crate::upstream::FindUpstream for PerlModuleDependency {
     fn find_upstream(&self) -> Option<crate::upstream::UpstreamMetadata> {
         let rt = tokio::runtime::Runtime::new().unwrap();
-        rt.block_on(upstream_ontologist::providers::perl::remote_cpan_data(&self.module)).ok()
+        rt.block_on(upstream_ontologist::providers::perl::remote_cpan_data(
+            &self.module,
+        ))
+        .ok()
     }
 }
 
 #[derive(Debug, Clone, Serialize, Deserialize)]
+/// A dependency on a predeclared Perl module.
+///
+/// This represents a dependency on a Perl module that is known by name but
+/// may map to a different actual module name.
 pub struct PerlPreDeclaredDependency {
     name: String,
 }
 
+/// Map a predeclared module name to an actual module name.
+///
+/// # Arguments
+/// * `name` - The predeclared module name
+///
+/// # Returns
+/// The actual module name if known
 fn known_predeclared_module(name: &str) -> Option<&str> {
     // TODO(jelmer): Can we obtain this information elsewhere?
     match name {
@@ -97,6 +138,13 @@ fn known_predeclared_module(name: &str) -> Option<&str> {
 }
 
 impl PerlPreDeclaredDependency {
+    /// Create a new predeclared Perl module dependency.
+    ///
+    /// # Arguments
+    /// * `name` - The name of the predeclared module
+    ///
+    /// # Returns
+    /// A new PerlPreDeclaredDependency
     pub fn new(name: &str) -> Self {
         Self {
             name: name.to_string(),
@@ -154,11 +202,21 @@ impl crate::buildlog::ToDependency
 }
 
 #[derive(Debug, Clone, Serialize, Deserialize)]
+/// A dependency on a Perl file.
+///
+/// This represents a dependency on a specific Perl file rather than a module.
 pub struct PerlFileDependency {
     filename: String,
 }
 
 impl PerlFileDependency {
+    /// Create a new Perl file dependency.
+    ///
+    /// # Arguments
+    /// * `filename` - The path to the Perl file
+    ///
+    /// # Returns
+    /// A new PerlFileDependency
     pub fn new(filename: &str) -> Self {
         Self {
             filename: filename.to_string(),
@@ -197,12 +255,23 @@ impl crate::buildlog::ToDependency for buildlog_consultant::problems::common::Mi
     }
 }
 
+/// A resolver for Perl module dependencies using CPAN.
+///
+/// This resolver installs Perl modules from CPAN using the cpan command.
 pub struct CPAN<'a> {
     session: &'a dyn Session,
     skip_tests: bool,
 }
 
 impl<'a> CPAN<'a> {
+    /// Create a new CPAN resolver.
+    ///
+    /// # Arguments
+    /// * `session` - The session to use for executing commands
+    /// * `skip_tests` - Whether to skip tests when installing modules
+    ///
+    /// # Returns
+    /// A new CPAN resolver
     pub fn new(session: &'a dyn Session, skip_tests: bool) -> Self {
         Self {
             session,
@@ -231,7 +300,7 @@ impl<'a> Installer for CPAN<'a> {
         scope: InstallationScope,
     ) -> Result<Explanation, Error> {
         if let Some(dep) = dep.as_any().downcast_ref::<PerlModuleDependency>() {
-            let cmd = self.cmd(&[&dep], scope)?;
+            let cmd = self.cmd(&[dep], scope)?;
             let explanation = Explanation {
                 message: "Install the following Perl modules".to_string(),
                 command: Some(cmd),
@@ -318,6 +387,7 @@ impl<'a> Installer for CPAN<'a> {
     }
 }
 
+/// Default paths where Perl modules can be installed.
 pub const DEFAULT_PERL_PATHS: &[&str] = &[
     "/usr/share/perl5",
     "/usr/lib/.*/perl5/.*",
@@ -332,6 +402,8 @@ impl crate::dependencies::debian::IntoDebianDependency for PerlModuleDependency
         &self,
         apt: &crate::debian::apt::AptManager,
     ) -> std::option::Option<std::vec::Vec<crate::dependencies::debian::DebianDependency>> {
+        use std::path::Path;
+
         let (regex, paths) = if let (Some(inc), Some(filename)) =
             (self.inc.as_ref(), self.filename.as_ref())
         {
@@ -409,3 +481,142 @@ impl crate::buildlog::ToDependency for buildlog_consultant::problems::common::Mi
         }))
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+    use crate::buildlog::ToDependency;
+
+    #[test]
+    fn test_perl_module_dependency_new() {
+        let dependency = PerlModuleDependency::new(
+            "Test::More",
+            Some("Test/More.pm"),
+            Some(vec!["/usr/share/perl5"]),
+        );
+        assert_eq!(dependency.module, "Test::More");
+        assert_eq!(dependency.filename, Some("Test/More.pm".to_string()));
+        assert_eq!(dependency.inc, Some(vec!["/usr/share/perl5".to_string()]));
+    }
+
+    #[test]
+    fn test_perl_module_dependency_simple() {
+        let dependency = PerlModuleDependency::simple("Test::More");
+        assert_eq!(dependency.module, "Test::More");
+        assert_eq!(dependency.filename, None);
+        assert_eq!(dependency.inc, None);
+    }
+
+    #[test]
+    fn test_perl_module_dependency_family() {
+        let dependency = PerlModuleDependency::simple("Test::More");
+        assert_eq!(dependency.family(), "perl-module");
+    }
+
+    #[test]
+    fn test_perl_module_dependency_as_any() {
+        let dependency = PerlModuleDependency::simple("Test::More");
+        let any_dep = dependency.as_any();
+        assert!(any_dep.downcast_ref::<PerlModuleDependency>().is_some());
+    }
+
+    #[test]
+    fn test_missing_perl_module_to_dependency() {
+        let problem = buildlog_consultant::problems::common::MissingPerlModule {
+            module: "Test::More".to_string(),
+            filename: Some("Test/More.pm".to_string()),
+            inc: None,
+            minimum_version: None,
+        };
+        let dependency = problem.to_dependency();
+        assert!(dependency.is_some());
+        let dep = dependency.unwrap();
+        assert_eq!(dep.family(), "perl-module");
+        let perl_dep = dep.as_any().downcast_ref::<PerlModuleDependency>().unwrap();
+        assert_eq!(perl_dep.module, "Test::More");
+        assert_eq!(perl_dep.filename, Some("Test/More.pm".to_string()));
+    }
+
+    #[test]
+    fn test_perl_predeclared_dependency_new() {
+        let dependency = PerlPreDeclaredDependency::new("auto_set_repository");
+        assert_eq!(dependency.name, "auto_set_repository");
+    }
+
+    #[test]
+    fn test_perl_predeclared_dependency_family() {
+        let dependency = PerlPreDeclaredDependency::new("auto_set_repository");
+        assert_eq!(dependency.family(), "perl-predeclared");
+    }
+
+    #[test]
+    fn test_perl_predeclared_dependency_as_any() {
+        let dependency = PerlPreDeclaredDependency::new("auto_set_repository");
+        let any_dep = dependency.as_any();
+        assert!(any_dep
+            .downcast_ref::<PerlPreDeclaredDependency>()
+            .is_some());
+    }
+
+    #[test]
+    fn test_known_predeclared_module() {
+        assert_eq!(
+            known_predeclared_module("auto_set_repository"),
+            Some("Module::Install::Repository")
+        );
+        assert_eq!(
+            known_predeclared_module("author_tests"),
+            Some("Module::Install::AuthorTests")
+        );
+        assert_eq!(known_predeclared_module("unknown_function"), None);
+    }
+
+    #[test]
+    fn test_perl_file_dependency_new() {
+        let dependency = PerlFileDependency::new("Test/More.pm");
+        assert_eq!(dependency.filename, "Test/More.pm");
+    }
+
+    #[test]
+    fn test_perl_file_dependency_family() {
+        let dependency = PerlFileDependency::new("Test/More.pm");
+        assert_eq!(dependency.family(), "perl-file");
+    }
+
+    #[test]
+    fn test_perl_file_dependency_as_any() {
+        let dependency = PerlFileDependency::new("Test/More.pm");
+        let any_dep = dependency.as_any();
+        assert!(any_dep.downcast_ref::<PerlFileDependency>().is_some());
+    }
+
+    #[test]
+    fn test_missing_perl_file_to_dependency() {
+        let problem = buildlog_consultant::problems::common::MissingPerlFile {
+            filename: "Test/More.pm".to_string(),
+            inc: None,
+        };
+        let dependency = problem.to_dependency();
+        assert!(dependency.is_some());
+        let dep = dependency.unwrap();
+        assert_eq!(dep.family(), "perl-file");
+        let perl_file_dep = dep.as_any().downcast_ref::<PerlFileDependency>().unwrap();
+        assert_eq!(perl_file_dep.filename, "Test/More.pm");
+    }
+
+    #[test]
+    fn test_cpan_new() {
+        let session = crate::session::plain::PlainSession::new();
+        let cpan = CPAN::new(&session, true);
+        assert!(cpan.skip_tests);
+    }
+
+    #[test]
+    fn test_cpan_cmd() {
+        let session = crate::session::plain::PlainSession::new();
+        let cpan = CPAN::new(&session, true);
+        let dependency = PerlModuleDependency::simple("Test::More");
+        let cmd = cpan.cmd(&[&dependency], InstallationScope::User).unwrap();
+        assert_eq!(cmd, vec!["cpan", "-i", "-T", "Test::More"]);
+    }
+}
