@@ -1,3 +1,9 @@
+//! Support for Python package dependencies.
+//!
+//! This module provides functionality for working with Python package dependencies,
+//! including parsing and resolving PEP 508 package requirements, and integrating
+//! with package managers.
+
 #[cfg(feature = "debian")]
 use crate::debian::apt::AptManager;
 #[cfg(feature = "debian")]
@@ -10,11 +16,15 @@ use debian_control::{
     lossless::relations::{Relation, Relations},
     relations::VersionConstraint,
 };
+use pep508_rs::pep440_rs;
 use serde::{Deserialize, Serialize};
-use std::path::{Path, PathBuf};
-use pep508_rs::pep440_rs as pep440_rs;
+use std::path::Path;
 
 #[derive(Debug, Clone, Serialize, Deserialize)]
+/// A dependency on a Python package.
+///
+/// This represents a dependency on a Python package from PyPI or another package
+/// repository. It uses PEP 508 requirement syntax for expressing version constraints.
 pub struct PythonPackageDependency(pep508_rs::Requirement);
 
 impl From<pep508_rs::Requirement> for PythonPackageDependency {
@@ -51,10 +61,22 @@ impl TryFrom<&str> for PythonPackageDependency {
 }
 
 impl PythonPackageDependency {
+    /// Get the package name.
+    ///
+    /// # Returns
+    /// The name of the Python package
     pub fn package(&self) -> String {
         self.0.name.to_string()
     }
 
+    /// Create a new dependency with a minimum version requirement.
+    ///
+    /// # Arguments
+    /// * `package` - The name of the Python package
+    /// * `min_version` - The minimum version required
+    ///
+    /// # Returns
+    /// A new PythonPackageDependency
     pub fn new_with_min_version(package: &str, min_version: &str) -> Self {
         Self(pep508_rs::Requirement {
             name: pep508_rs::PackageName::new(package.to_string()).unwrap(),
@@ -65,6 +87,13 @@ impl PythonPackageDependency {
         })
     }
 
+    /// Create a simple dependency with no version constraints.
+    ///
+    /// # Arguments
+    /// * `package` - The name of the Python package
+    ///
+    /// # Returns
+    /// A new PythonPackageDependency
     pub fn simple(package: &str) -> Self {
         Self(pep508_rs::Requirement {
             name: pep508_rs::PackageName::new(package.to_string()).unwrap(),
@@ -76,6 +105,13 @@ impl PythonPackageDependency {
     }
 }
 
+/// Convert a minimum version string to a PEP 508 VersionOrUrl.
+///
+/// # Arguments
+/// * `min_version` - The minimum version string
+///
+/// # Returns
+/// A PEP 508 VersionOrUrl with a >= constraint
 fn min_version_as_version_or_url(min_version: &str) -> pep508_rs::VersionOrUrl {
     use std::str::FromStr;
     let version_specifiers = std::iter::once(
@@ -89,6 +125,13 @@ fn min_version_as_version_or_url(min_version: &str) -> pep508_rs::VersionOrUrl {
     pep508_rs::VersionOrUrl::VersionSpecifier(version_specifiers)
 }
 
+/// Create a PEP 508 marker for a specific Python major version.
+///
+/// # Arguments
+/// * `major_version` - The Python major version (e.g., 2 or 3)
+///
+/// # Returns
+/// A PEP 508 MarkerTree that requires the specified Python version
 fn major_python_version_as_marker(major_version: u32) -> pep508_rs::MarkerTree {
     pep508_rs::MarkerTree::expression(pep508_rs::MarkerExpression::Version {
         key: pep508_rs::MarkerValueVersion::PythonVersion,
@@ -106,9 +149,13 @@ impl crate::buildlog::ToDependency
             .minimum_version
             .as_ref()
             .map(|min_version| min_version_as_version_or_url(min_version));
-        let marker = self.python_version.as_ref().map(|python_major_version| {
-            major_python_version_as_marker(*python_major_version as u32)
-        }).unwrap_or(pep508_rs::MarkerTree::TRUE);
+        let marker = self
+            .python_version
+            .as_ref()
+            .map(|python_major_version| {
+                major_python_version_as_marker(*python_major_version as u32)
+            })
+            .unwrap_or(pep508_rs::MarkerTree::TRUE);
 
         let requirement = pep508_rs::Requirement {
             name: pep508_rs::PackageName::new(self.distribution.clone()).unwrap(),
@@ -142,7 +189,9 @@ impl crate::dependencies::debian::FromDebianDependency for PythonPackageDependen
                 name: pep508_rs::PackageName::new(name.to_owned()).unwrap(),
                 version_or_url: min_version
                     .map(|x| min_version_as_version_or_url(&x.upstream_version)),
-                marker: major_python_version.map(major_python_version_as_marker).unwrap_or(pep508_rs::MarkerTree::TRUE),
+                marker: major_python_version
+                    .map(major_python_version_as_marker)
+                    .unwrap_or(pep508_rs::MarkerTree::TRUE),
                 extras: vec![],
                 origin: None,
             },
@@ -151,15 +200,27 @@ impl crate::dependencies::debian::FromDebianDependency for PythonPackageDependen
 }
 
 #[derive(Debug, Clone, Default, Copy, Serialize, Deserialize)]
+/// Supported Python implementations and versions.
+///
+/// This enum represents the different Python implementations and versions
+/// that can be used to satisfy Python package dependencies.
 pub enum PythonVersion {
+    /// CPython 2.x
     CPython2,
+    /// CPython 3.x (default)
     #[default]
     CPython3,
+    /// PyPy (Python 2 compatible)
     PyPy,
+    /// PyPy (Python 3 compatible)
     PyPy3,
 }
 
 impl PythonVersion {
+    /// Get the executable name for this Python version.
+    ///
+    /// # Returns
+    /// The name of the Python executable
     pub fn executable(&self) -> &'static str {
         match self {
             PythonVersion::CPython2 => "python2",
@@ -207,11 +268,16 @@ impl Dependency for PythonPackageDependency {
 impl crate::upstream::FindUpstream for PythonPackageDependency {
     fn find_upstream(&self) -> Option<crate::upstream::UpstreamMetadata> {
         let rt = tokio::runtime::Runtime::new().unwrap();
-        rt.block_on(upstream_ontologist::providers::python::remote_pypi_metadata(&self.package())).ok()
+        rt.block_on(upstream_ontologist::providers::python::remote_pypi_metadata(&self.package()))
+            .ok()
     }
 }
 
 #[derive(Debug, Clone, Serialize, Deserialize)]
+/// A dependency on a Python module.
+///
+/// This represents a dependency on a specific Python module (importable name)
+/// rather than a package. Used for checking if specific imports will work.
 pub struct PythonModuleDependency {
     module: String,
     minimum_version: Option<String>,
@@ -219,14 +285,34 @@ pub struct PythonModuleDependency {
 }
 
 impl PythonModuleDependency {
-    pub fn new(module: &str, minimum_version: Option<&str>, python_version: Option<PythonVersion>) -> Self {
+    /// Create a new Python module dependency.
+    ///
+    /// # Arguments
+    /// * `module` - The name of the module to import
+    /// * `minimum_version` - Optional minimum version requirement
+    /// * `python_version` - Optional specific Python version to use
+    ///
+    /// # Returns
+    /// A new PythonModuleDependency
+    pub fn new(
+        module: &str,
+        minimum_version: Option<&str>,
+        python_version: Option<PythonVersion>,
+    ) -> Self {
         Self {
             module: module.to_string(),
             minimum_version: minimum_version.map(|s| s.to_string()),
-            python_version
+            python_version,
         }
     }
 
+    /// Create a simple Python module dependency with no version constraints.
+    ///
+    /// # Arguments
+    /// * `module` - The name of the module to import
+    ///
+    /// # Returns
+    /// A new PythonModuleDependency with no version constraints
     pub fn simple(module: &str) -> Self {
         Self {
             module: module.to_string(),
@@ -235,6 +321,10 @@ impl PythonModuleDependency {
         }
     }
 
+    /// Get the Python executable to use for this dependency.
+    ///
+    /// # Returns
+    /// The name of the Python executable
     fn python_executable(&self) -> &str {
         self.python_version.unwrap_or_default().executable()
     }
@@ -286,15 +376,30 @@ impl Dependency for PythonModuleDependency {
     }
 }
 
+/// Resolver for Python packages using pip.
+///
+/// This resolver installs Python packages from PyPI using pip.
 pub struct PypiResolver<'a> {
     session: &'a dyn Session,
 }
 
 impl<'a> PypiResolver<'a> {
+    /// Create a new PypiResolver with the specified session.
+    ///
+    /// # Arguments
+    /// * `session` - The session to use for executing commands
     pub fn new(session: &'a dyn Session) -> Self {
         Self { session }
     }
 
+    /// Generate the pip command for installing the specified requirements.
+    ///
+    /// # Arguments
+    /// * `reqs` - The Python package dependencies to install
+    /// * `scope` - The installation scope (user or global)
+    ///
+    /// # Returns
+    /// The pip command as a vector of strings
     pub fn cmd(
         &self,
         reqs: Vec<&PythonPackageDependency>,
@@ -356,6 +461,14 @@ impl<'a> Installer for PypiResolver<'a> {
 }
 
 #[cfg(feature = "debian")]
+/// Convert Python version specifiers to Debian package version constraints.
+///
+/// # Arguments
+/// * `pkg_name` - The name of the Debian package
+/// * `version_specifiers` - The Python version specifiers (PEP 440)
+///
+/// # Returns
+/// Debian package relations with appropriate version constraints
 pub fn python_version_specifiers_to_debian(
     pkg_name: &str,
     version_specifiers: Option<&pep440_rs::VersionSpecifiers>,
@@ -448,9 +561,14 @@ fn find_python_version(marker: Vec<Vec<pep508_rs::MarkerExpression>>) -> Option<
                 let version = specifier.version();
                 major_version = Some(version.release()[0] as u32);
             }
-            pep508_rs::MarkerExpression::String { key: pep508_rs::MarkerValueString::PlatformPythonImplementation, operator: pep508_rs::MarkerOperator::Equal, value } => match value.as_str() {
-                "PyPy" => { implementation = Some("PyPy"); },
-                _ => {}
+            pep508_rs::MarkerExpression::String {
+                key: pep508_rs::MarkerValueString::PlatformPythonImplementation,
+                operator: pep508_rs::MarkerOperator::Equal,
+                value,
+            } => {
+                if value.as_str() == "PyPy" {
+                    implementation = Some("PyPy");
+                }
             }
             _ => {}
         }
@@ -462,11 +580,14 @@ fn find_python_version(marker: Vec<Vec<pep508_rs::MarkerExpression>>) -> Option<
         (Some(3), Some("PyPy")) | (None, Some("PyPy")) => Some(PythonVersion::PyPy3),
         (Some(2), Some("PyPy")) => Some(PythonVersion::PyPy),
         _ => {
-            log::warn!("Unknown python implementation / version: {:?} {:?}", major_version, implementation);
+            log::warn!(
+                "Unknown python implementation / version: {:?} {:?}",
+                major_version,
+                implementation
+            );
             None
         }
     }
-
 }
 
 #[cfg(feature = "debian")]
@@ -531,7 +652,7 @@ fn get_package_for_python_package(
 }
 
 #[cfg(any(feature = "debian", test))]
-fn get_possible_python3_paths_for_python_object(mut object_path: &str) -> Vec<PathBuf> {
+fn get_possible_python3_paths_for_python_object(mut object_path: &str) -> Vec<std::path::PathBuf> {
     let mut cpython3_regexes = vec![];
     loop {
         cpython3_regexes.extend([
@@ -563,7 +684,7 @@ fn get_possible_python3_paths_for_python_object(mut object_path: &str) -> Vec<Pa
 }
 
 #[cfg(feature = "debian")]
-fn get_possible_pypy_paths_for_python_object(mut object_path: &str) -> Vec<PathBuf> {
+fn get_possible_pypy_paths_for_python_object(mut object_path: &str) -> Vec<std::path::PathBuf> {
     let mut pypy_regexes = vec![];
     loop {
         pypy_regexes.extend([
@@ -588,7 +709,7 @@ fn get_possible_pypy_paths_for_python_object(mut object_path: &str) -> Vec<PathB
 }
 
 #[cfg(feature = "debian")]
-fn get_possible_python2_paths_for_python_object(mut object_path: &str) -> Vec<PathBuf> {
+fn get_possible_python2_paths_for_python_object(mut object_path: &str) -> Vec<std::path::PathBuf> {
     let mut cpython2_regexes = vec![];
     loop {
         cpython2_regexes.extend([
@@ -690,17 +811,32 @@ impl crate::buildlog::ToDependency
 }
 
 #[derive(Debug, Clone, Serialize, Deserialize)]
+/// A dependency on Python itself.
+///
+/// This represents a dependency on the Python interpreter or development files.
 pub struct PythonDependency {
+    /// The minimum Python version required, if any.
     pub min_version: Option<String>,
 }
 
 impl PythonDependency {
+    /// Create a new Python dependency with an optional minimum version.
+    ///
+    /// # Arguments
+    /// * `min_version` - The minimum Python version required (e.g., "3.8")
+    ///
+    /// # Returns
+    /// A new PythonDependency
     pub fn new(min_version: Option<&str>) -> Self {
         Self {
             min_version: min_version.map(|s| s.to_string()),
         }
     }
 
+    /// Create a simple Python dependency with no version constraints.
+    ///
+    /// # Returns
+    /// A new PythonDependency with no version constraints
     pub fn simple() -> Self {
         Self { min_version: None }
     }
@@ -719,6 +855,65 @@ impl PythonDependency {
     }
 }
 
+#[cfg(test)]
+mod python_dep_tests {
+    use super::*;
+
+    #[test]
+    fn test_python_dependency_new() {
+        let dependency = PythonDependency::new(Some("3.6"));
+        assert_eq!(dependency.min_version, Some("3.6".to_string()));
+    }
+
+    #[test]
+    fn test_python_dependency_simple() {
+        let dependency = PythonDependency::simple();
+        assert_eq!(dependency.min_version, None);
+    }
+
+    #[test]
+    fn test_python_dependency_family() {
+        let dependency = PythonDependency::simple();
+        assert_eq!(dependency.family(), "python");
+    }
+
+    #[test]
+    fn test_python_dependency_executable_python3() {
+        let dependency = PythonDependency::new(Some("3.6"));
+        assert_eq!(dependency.executable(), "python3");
+    }
+
+    #[test]
+    fn test_python_dependency_executable_python2() {
+        let dependency = PythonDependency::new(Some("2.7"));
+        assert_eq!(dependency.executable(), "python");
+    }
+
+    #[test]
+    fn test_python_dependency_executable_default() {
+        let dependency = PythonDependency::simple();
+        assert_eq!(dependency.executable(), "python3");
+    }
+
+    #[test]
+    fn test_python_dependency_from_specs() {
+        use std::str::FromStr;
+        let specs = pep440_rs::VersionSpecifiers::from_str(">=3.6").unwrap();
+        let dependency = PythonDependency::from(&specs);
+        // The actual version might be "3.6" or "3.6.0" depending on the pep440_rs version, so we just check that it contains "3.6"
+        assert!(dependency.min_version.is_some());
+        assert!(dependency.min_version.as_ref().unwrap().contains("3.6"));
+    }
+
+    #[test]
+    fn test_python_dependency_from_specs_no_version() {
+        use std::str::FromStr;
+        let specs = pep440_rs::VersionSpecifiers::from_str("==3.6").unwrap();
+        let dependency = PythonDependency::from(&specs);
+        assert_eq!(dependency.min_version, None);
+    }
+}
+
 impl Dependency for PythonDependency {
     fn family(&self) -> &'static str {
         "python"
@@ -825,6 +1020,8 @@ mod tests {
 
     #[test]
     fn test_paths() {
+        use std::path::PathBuf;
+
         assert_eq!(
             vec![
                 PathBuf::from("/usr/lib/python3/dist\\-packages/dulwich/__init__\\.py"),
